@@ -4,7 +4,7 @@ fs_tree=$1
 # the files we check here are part of the libc package,
 # so one of them should be here, depending on CPU architecture.
 
-if ls "$fs_tree/etc/ld.so.conf.d/i686-linux-gnu.conf" >/dev/null 2>&1
+if ls "$fs_tree/etc/ld.so.conf.d/i"*"86-linux-gnu.conf" >/dev/null 2>&1
 then
     exit 0  # OK
 fi
